@@ -287,7 +287,10 @@
 
 /* Use 64KiB tables */
 #ifndef LTC_NO_TABLES
-/*   #define LTC_GCM_TABLES */
+ #if (!defined(__hpux) && !defined(__hpux__)) || (!defined(__ia64) && !defined(__ia64__))
+   /* LTC_GCM_TABLES does not work on HP-UX/ITANIUM */
+   #define LTC_GCM_TABLES
+ #endif
 #endif
 
 /* USE SSE2? requires GCC works on x86_32 and x86_64*/
